summaryrefslogtreecommitdiffstats
path: root/src/gui/general/RosegardenCanvasView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/general/RosegardenCanvasView.h')
-rw-r--r--src/gui/general/RosegardenCanvasView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/general/RosegardenCanvasView.h b/src/gui/general/RosegardenCanvasView.h
index 02faef2..01bca28 100644
--- a/src/gui/general/RosegardenCanvasView.h
+++ b/src/gui/general/RosegardenCanvasView.h
@@ -43,7 +43,7 @@ namespace Rosegarden
/**
* A TQCanvasView with an auxiliary horiz. scrollbar
* That scrollbar should be provided by the tqparent widget
* (typically an EditView). The RosegardenCanvasView keeps
* the auxilliary horiz. scrollbar range in sync with the
* one of its own scrollbar with slotUpdate().
@@ -55,7 +55,7 @@ class RosegardenCanvasView : public TQCanvasView
TQ_OBJECT
public:
RosegardenCanvasView(TQCanvas*,
- TQWidget* tqparent=0, const char* name=0, WFlags f=0);
+ TQWidget* parent=0, const char* name=0, WFlags f=0);
/**
* EditTool::handleMouseMove() returns a OR-ed combination of these
@@ -43,7 +43,7 @@ namespace Rosegarden
/**
* A TQCanvasView with an auxiliary horiz. scrollbar
- * That scrollbar should be provided by the tqparent widget
+ * That scrollbar should be provided by the parent widget
* (typically an EditView). The RosegardenCanvasView keeps
* the auxilliary horiz. scrollbar range in sync with the